Changelog
=================================================

v0.8.0
------
*    documentation improvements
*    automated notebook testing
*    use sympy.I and sympy.pi

v0.7.0
------
*    add Poincaré sphere support
*    allow lists of Jones/Stokes vector to be processed
*    add some basic tox tests

v0.6.0
------
*    use sphinx for documentation
*    host docs on https://pypolar.readthedocs.io
*    remove unneeded files from pip installation
*    start using tox for testing

v0.5.1
------
*    fix jones.intensity() and sym_jones.intensity()

v0.5.0
------
*    add symbolic routines
*    add more mueller functions
*    rename some stuff
*    modify names for polarization ellipse
*    improve readme
*    split visualization into separate document

v0.3.1
------
*     hopefully fix packaging
*     fix phase for TIR of dielectrics

v0.3.0
------
*     add basic routines for Mueller and Stokes vectors
*     rename a bunch of routines
*     repackage with the intent that modules will be used separately
*     add Jupyter notebooks to provide basic documentation
*     add basic ellipsometry support

v0.2.0
------
*     add Fresnel transmission
*     handle total internal reflection better

v0.1.1
------
*     fix packaging error

v0.1.0
------
*     initial checkin
